@@ -183,7 +183,25 @@ extern void e_marshal_INT__POINTER (GClosure     *closure,
                                     gpointer      invocation_hint,
                                     gpointer      marshal_data);
 
-/* NONE:INT,INT (e-marshal.list:23) */
+/* NONE:BOXED,INT (e-marshal.list:23) */
+extern void e_marshal_VOID__BOXED_INT (GClosure     *closure,
+                                       GValue       *return_value,
+                                       guint         n_param_values,
+                                       const GValue *param_values,
+                                       gpointer      invocation_hint,
+                                       gpointer      marshal_data);
+#define e_marshal_NONE__BOXED_INT	e_marshal_VOID__BOXED_INT
+
+/* NONE:ENUM,OBJECT,OBJECT (e-marshal.list:24) */
+extern void e_marshal_VOID__ENUM_OBJECT_OBJECT (GClosure     *closure,
+                                                GValue       *return_value,
+                                                guint         n_param_values,
+                                                const GValue *param_values,
+                                                gpointer      invocation_hint,
+                                                gpointer      marshal_data);
+#define e_marshal_NONE__ENUM_OBJECT_OBJECT	e_marshal_VOID__ENUM_OBJECT_OBJECT
+
+/* NONE:INT,INT (e-marshal.list:25) */
 extern void e_marshal_VOID__INT_INT (GClosure     *closure,
                                      GValue       *return_value,
                                      guint         n_param_values,
@@ -192,7 +210,7 @@ extern void e_marshal_VOID__INT_INT (GClosure     *closure,
                                      gpointer      marshal_data);
 #define e_marshal_NONE__INT_INT	e_marshal_VOID__INT_INT
 
-/* NONE:INT,INT,BOXED (e-marshal.list:24) */
+/* NONE:INT,INT,BOXED (e-marshal.list:26) */
 extern void e_marshal_VOID__INT_INT_BOXED (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -201,7 +219,7 @@ extern void e_marshal_VOID__INT_INT_BOXED (GClosure     *closure,
                                            gpointer      marshal_data);
 #define e_marshal_NONE__INT_INT_BOXED	e_marshal_VOID__INT_INT_BOXED
 
-/* NONE:INT,INT,OBJECT (e-marshal.list:25) */
+/* NONE:INT,INT,OBJECT (e-marshal.list:27) */
 extern void e_marshal_VOID__INT_INT_OBJECT (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -210,7 +228,7 @@ extern void e_marshal_VOID__INT_INT_OBJECT (GClosure     *closure,
                                             gpointer      marshal_data);
 #define e_marshal_NONE__INT_INT_OBJECT	e_marshal_VOID__INT_INT_OBJECT
 
-/* NONE:INT,INT,OBJECT,BOXED,UINT,UINT (e-marshal.list:26) */
+/* NONE:INT,INT,OBJECT,BOXED,UINT,UINT (e-marshal.list:28) */
 extern void e_marshal_VOID__INT_INT_OBJECT_BOXED_UINT_UINT (GClosure     *closure,
                                                             GValue       *return_value,
                                                             guint         n_param_values,
@@ -219,7 +237,7 @@ extern void e_marshal_VOID__INT_INT_OBJECT_BOXED_UINT_UINT (GClosure     *closur
                                                             gpointer      marshal_data);
 #define e_marshal_NONE__INT_INT_OBJECT_BOXED_UINT_UINT	e_marshal_VOID__INT_INT_OBJECT_BOXED_UINT_UINT
 
-/* NONE:INT,INT,OBJECT,INT,INT,BOXED,UINT,UINT (e-marshal.list:27) */
+/* NONE:INT,INT,OBJECT,INT,INT,BOXED,UINT,UINT (e-marshal.list:29) */
 extern void e_marshal_VOID__INT_INT_OBJECT_INT_INT_BOXED_UINT_UINT (GClosure     *closure,
                                                                     GValue       *return_value,
                                                                     guint         n_param_values,
@@ -228,7 +246,7 @@ extern void e_marshal_VOID__INT_INT_OBJECT_INT_INT_BOXED_UINT_UINT (GClosure
                                                                     gpointer      marshal_data);
 #define e_marshal_NONE__INT_INT_OBJECT_INT_INT_BOXED_UINT_UINT	e_marshal_VOID__INT_INT_OBJECT_INT_INT_BOXED_UINT_UINT
 
-/* NONE:INT,INT,OBJECT,UINT (e-marshal.list:28) */
+/* NONE:INT,INT,OBJECT,UINT (e-marshal.list:30) */
 extern void e_marshal_VOID__INT_INT_OBJECT_UINT (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
@@ -237,7 +255,7 @@ extern void e_marshal_VOID__INT_INT_OBJECT_UINT (GClosure     *closure,
                                                  gpointer      marshal_data);
 #define e_marshal_NONE__INT_INT_OBJECT_UINT	e_marshal_VOID__INT_INT_OBJECT_UINT
 
-/* NONE:INT,OBJECT (e-marshal.list:29) */
+/* NONE:INT,OBJECT (e-marshal.list:31) */
 extern void e_marshal_VOID__INT_OBJECT (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
@@ -246,7 +264,7 @@ extern void e_marshal_VOID__INT_OBJECT (GClosure     *closure,
                                         gpointer      marshal_data);
 #define e_marshal_NONE__INT_OBJECT	e_marshal_VOID__INT_OBJECT
 
-/* NONE:INT,POINTER (e-marshal.list:30) */
+/* NONE:INT,POINTER (e-marshal.list:32) */
 extern void e_marshal_VOID__INT_POINTER (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
@@ -255,7 +273,7 @@ extern void e_marshal_VOID__INT_POINTER (GClosure     *closure,
                                          gpointer      marshal_data);
 #define e_marshal_NONE__INT_POINTER	e_marshal_VOID__INT_POINTER
 
-/* NONE:INT,POINTER,INT,BOXED (e-marshal.list:31) */
+/* NONE:INT,POINTER,INT,BOXED (e-marshal.list:33) */
 extern void e_marshal_VOID__INT_POINTER_INT_BOXED (GClosure     *closure,
                                                    GValue       *return_value,
                                                    guint         n_param_values,
@@ -264,7 +282,7 @@ extern void e_marshal_VOID__INT_POINTER_INT_BOXED (GClosure     *closure,
                                                    gpointer      marshal_data);
 #define e_marshal_NONE__INT_POINTER_INT_BOXED	e_marshal_VOID__INT_POINTER_INT_BOXED
 
-/* NONE:INT,POINTER,INT,OBJECT (e-marshal.list:32) */
+/* NONE:INT,POINTER,INT,OBJECT (e-marshal.list:34) */
 extern void e_marshal_VOID__INT_POINTER_INT_OBJECT (GClosure     *closure,
                                                     GValue       *return_value,
                                                     guint         n_param_values,
@@ -273,7 +291,7 @@ extern void e_marshal_VOID__INT_POINTER_INT_OBJECT (GClosure     *closure,
                                                     gpointer      marshal_data);
 #define e_marshal_NONE__INT_POINTER_INT_OBJECT	e_marshal_VOID__INT_POINTER_INT_OBJECT
 
-/* NONE:INT,POINTER,INT,OBJECT,BOXED,UINT,UINT (e-marshal.list:33) */
+/* NONE:INT,POINTER,INT,OBJECT,BOXED,UINT,UINT (e-marshal.list:35) */
 extern void e_marshal_VOID__INT_POINTER_INT_OBJECT_BOXED_UINT_UINT (GClosure     *closure,
                                                                     GValue       *return_value,
                                                                     guint         n_param_values,
@@ -282,7 +300,7 @@ extern void e_marshal_VOID__INT_POINTER_INT_OBJECT_BOXED_UINT_UINT (GClosure
                                                                     gpointer      marshal_data);
 #define e_marshal_NONE__INT_POINTER_INT_OBJECT_BOXED_UINT_UINT	e_marshal_VOID__INT_POINTER_INT_OBJECT_BOXED_UINT_UINT
 
-/* NONE:INT,POINTER,INT,OBJECT,INT,INT,BOXED,UINT,UINT (e-marshal.list:34) */
+/* NONE:INT,POINTER,INT,OBJECT,INT,INT,BOXED,UINT,UINT (e-marshal.list:36) */
 extern void e_marshal_VOID__INT_POINTER_INT_OBJECT_INT_INT_BOXED_UINT_UINT (GClosure     *closure,
                                                                             GValue       *return_value,
                                                                             guint         n_param_values,
@@ -291,7 +309,7 @@ extern void e_marshal_VOID__INT_POINTER_INT_OBJECT_INT_INT_BOXED_UINT_UINT (GClo
                                                                             gpointer      marshal_data);
 #define e_marshal_NONE__INT_POINTER_INT_OBJECT_INT_INT_BOXED_UINT_UINT	e_marshal_VOID__INT_POINTER_INT_OBJECT_INT_INT_BOXED_UINT_UINT
 
-/* NONE:INT,POINTER,INT,OBJECT,UINT (e-marshal.list:35) */
+/* NONE:INT,POINTER,INT,OBJECT,UINT (e-marshal.list:37) */
 extern void e_marshal_VOID__INT_POINTER_INT_OBJECT_UINT (GClosure     *closure,
                                                          GValue       *return_value,
                                                          guint         n_param_values,
@@ -300,16 +318,7 @@ extern void e_marshal_VOID__INT_POINTER_INT_OBJECT_UINT (GClosure     *closure,
                                                          gpointer      marshal_data);
 #define e_marshal_NONE__INT_POINTER_INT_OBJECT_UINT	e_marshal_VOID__INT_POINTER_INT_OBJECT_UINT
 
-/* NONE:INT,STRING,INT (e-marshal.list:36) */
-extern void e_marshal_VOID__INT_STRING_INT (GClosure     *closure,
-                                            GValue       *return_value,
-                                            guint         n_param_values,
-                                            const GValue *param_values,
-                                            gpointer      invocation_hint,
-                                            gpointer      marshal_data);
-#define e_marshal_NONE__INT_STRING_INT	e_marshal_VOID__INT_STRING_INT
-
-/* NONE:LONG,LONG (e-marshal.list:37) */
+/* NONE:LONG,LONG (e-marshal.list:38) */
 extern void e_marshal_VOID__LONG_LONG (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
@@ -318,7 +327,7 @@ extern void e_marshal_VOID__LONG_LONG (GClosure     *closure,
                                        gpointer      marshal_data);
 #define e_marshal_NONE__LONG_LONG	e_marshal_VOID__LONG_LONG
 
-/* NONE:OBJECT,BOOLEAN (e-marshal.list:38) */
+/* NONE:OBJECT,BOOLEAN (e-marshal.list:39) */
 extern void e_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -327,7 +336,7 @@ extern void e_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                             gpointer      marshal_data);
 #define e_marshal_NONE__OBJECT_BOOLEAN	e_marshal_VOID__OBJECT_BOOLEAN
 
-/* NONE:OBJECT,DOUBLE,DOUBLE,BOOLEAN (e-marshal.list:39) */
+/* NONE:OBJECT,DOUBLE,DOUBLE,BOOLEAN (e-marshal.list:40) */
 extern void e_marshal_VOID__OBJECT_DOUBLE_DOUBLE_BOOLEAN (GClosure     *closure,
                                                           GValue       *return_value,
                                                           guint         n_param_values,
@@ -336,7 +345,7 @@ extern void e_marshal_VOID__OBJECT_DOUBLE_DOUBLE_BOOLEAN (GClosure     *closure,
                                                           gpointer      marshal_data);
 #define e_marshal_NONE__OBJECT_DOUBLE_DOUBLE_BOOLEAN	e_marshal_VOID__OBJECT_DOUBLE_DOUBLE_BOOLEAN
 
-/* NONE:OBJECT,OBJECT (e-marshal.list:40) */
+/* NONE:OBJECT,OBJECT (e-marshal.list:41) */
 extern void e_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -345,7 +354,7 @@ extern void e_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                            gpointer      marshal_data);
 #define e_marshal_NONE__OBJECT_OBJECT	e_marshal_VOID__OBJECT_OBJECT
 
-/* NONE:OBJECT,STRING (e-marshal.list:41) */
+/* NONE:OBJECT,STRING (e-marshal.list:42) */
 extern void e_marshal_VOID__OBJECT_STRING (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -354,7 +363,7 @@ extern void e_marshal_VOID__OBJECT_STRING (GClosure     *closure,
                                            gpointer      marshal_data);
 #define e_marshal_NONE__OBJECT_STRING	e_marshal_VOID__OBJECT_STRING
 
-/* NONE:OBJECT,STRING,INT (e-marshal.list:42) */
+/* NONE:OBJECT,STRING,INT (e-marshal.list:43) */
 extern void e_marshal_VOID__OBJECT_STRING_INT (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
@@ -363,7 +372,16 @@ extern void e_marshal_VOID__OBJECT_STRING_INT (GClosure     *closure,
                                                gpointer      marshal_data);
 #define e_marshal_NONE__OBJECT_STRING_INT	e_marshal_VOID__OBJECT_STRING_INT
 
-/* NONE:OBJECT,STRING,STRING (e-marshal.list:43) */
+/* NONE:OBJECT,STRING,INT,STRING,STRING,STRING (e-marshal.list:44) */
+extern void e_marshal_VOID__OBJECT_STRING_INT_STRING_STRING_STRING (GClosure     *closure,
+                                                                    GValue       *return_value,
+                                                                    guint         n_param_values,
+                                                                    const GValue *param_values,
+                                                                    gpointer      invocation_hint,
+                                                                    gpointer      marshal_data);
+#define e_marshal_NONE__OBJECT_STRING_INT_STRING_STRING_STRING	e_marshal_VOID__OBJECT_STRING_INT_STRING_STRING_STRING
+
+/* NONE:OBJECT,STRING,STRING (e-marshal.list:45) */
 extern void e_marshal_VOID__OBJECT_STRING_STRING (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
@@ -372,16 +390,16 @@ extern void e_marshal_VOID__OBJECT_STRING_STRING (GClosure     *closure,
                                                   gpointer      marshal_data);
 #define e_marshal_NONE__OBJECT_STRING_STRING	e_marshal_VOID__OBJECT_STRING_STRING
 
-/* NONE:OBJECT,STRING,STRING,INT,STRING,STRING,STRING (e-marshal.list:44) */
-extern void e_marshal_VOID__OBJECT_STRING_STRING_INT_STRING_STRING_STRING (GClosure     *closure,
-                                                                           GValue       *return_value,
-                                                                           guint         n_param_values,
-                                                                           const GValue *param_values,
-                                                                           gpointer      invocation_hint,
-                                                                           gpointer      marshal_data);
-#define e_marshal_NONE__OBJECT_STRING_STRING_INT_STRING_STRING_STRING	e_marshal_VOID__OBJECT_STRING_STRING_INT_STRING_STRING_STRING
+/* NONE:OBJECT,STRING,UINT (e-marshal.list:46) */
+extern void e_marshal_VOID__OBJECT_STRING_UINT (GClosure     *closure,
+                                                GValue       *return_value,
+                                                guint         n_param_values,
+                                                const GValue *param_values,
+                                                gpointer      invocation_hint,
+                                                gpointer      marshal_data);
+#define e_marshal_NONE__OBJECT_STRING_UINT	e_marshal_VOID__OBJECT_STRING_UINT
 
-/* NONE:POINTER,INT (e-marshal.list:45) */
+/* NONE:POINTER,INT (e-marshal.list:47) */
 extern void e_marshal_VOID__POINTER_INT (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
@@ -390,7 +408,7 @@ extern void e_marshal_VOID__POINTER_INT (GClosure     *closure,
                                          gpointer      marshal_data);
 #define e_marshal_NONE__POINTER_INT	e_marshal_VOID__POINTER_INT
 
-/* NONE:POINTER,INT,INT,INT,INT (e-marshal.list:46) */
+/* NONE:POINTER,INT,INT,INT,INT (e-marshal.list:48) */
 extern void e_marshal_VOID__POINTER_INT_INT_INT_INT (GClosure     *closure,
                                                      GValue       *return_value,
                                                      guint         n_param_values,
@@ -399,7 +417,7 @@ extern void e_marshal_VOID__POINTER_INT_INT_INT_INT (GClosure     *closure,
                                                      gpointer      marshal_data);
 #define e_marshal_NONE__POINTER_INT_INT_INT_INT	e_marshal_VOID__POINTER_INT_INT_INT_INT
 
-/* NONE:POINTER,INT,OBJECT (e-marshal.list:47) */
+/* NONE:POINTER,INT,OBJECT (e-marshal.list:49) */
 extern void e_marshal_VOID__POINTER_INT_OBJECT (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -408,7 +426,7 @@ extern void e_marshal_VOID__POINTER_INT_OBJECT (GClosure     *closure,
                                                 gpointer      marshal_data);
 #define e_marshal_NONE__POINTER_INT_OBJECT	e_marshal_VOID__POINTER_INT_OBJECT
 
-/* NONE:POINTER,OBJECT (e-marshal.list:48) */
+/* NONE:POINTER,OBJECT (e-marshal.list:50) */
 extern void e_marshal_VOID__POINTER_OBJECT (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -417,7 +435,7 @@ extern void e_marshal_VOID__POINTER_OBJECT (GClosure     *closure,
                                             gpointer      marshal_data);
 #define e_marshal_NONE__POINTER_OBJECT	e_marshal_VOID__POINTER_OBJECT
 
-/* NONE:POINTER,POINTER (e-marshal.list:49) */
+/* NONE:POINTER,POINTER (e-marshal.list:51) */
 extern void e_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -426,7 +444,7 @@ extern void e_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                              gpointer      marshal_data);
 #define e_marshal_NONE__POINTER_POINTER	e_marshal_VOID__POINTER_POINTER
 
-/* NONE:POINTER,POINTER,INT (e-marshal.list:50) */
+/* NONE:POINTER,POINTER,INT (e-marshal.list:52) */
 extern void e_marshal_VOID__POINTER_POINTER_INT (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
@@ -435,7 +453,7 @@ extern void e_marshal_VOID__POINTER_POINTER_INT (GClosure     *closure,
                                                  gpointer      marshal_data);
 #define e_marshal_NONE__POINTER_POINTER_INT	e_marshal_VOID__POINTER_POINTER_INT
 
-/* NONE:STRING,DOUBLE (e-marshal.list:51) */
+/* NONE:STRING,DOUBLE (e-marshal.list:53) */
 extern void e_marshal_VOID__STRING_DOUBLE (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -444,7 +462,16 @@ extern void e_marshal_VOID__STRING_DOUBLE (GClosure     *closure,
                                            gpointer      marshal_data);
 #define e_marshal_NONE__STRING_DOUBLE	e_marshal_VOID__STRING_DOUBLE
 
-/* NONE:STRING,INT,INT (e-marshal.list:52) */
+/* NONE:STRING,INT (e-marshal.list:54) */
+extern void e_marshal_VOID__STRING_INT (GClosure     *closure,
+                                        GValue       *return_value,
+                                        guint         n_param_values,
+                                        const GValue *param_values,
+                                        gpointer      invocation_hint,
+                                        gpointer      marshal_data);
+#define e_marshal_NONE__STRING_INT	e_marshal_VOID__STRING_INT
+
+/* NONE:STRING,INT,INT (e-marshal.list:55) */
 extern void e_marshal_VOID__STRING_INT_INT (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -453,7 +480,7 @@ extern void e_marshal_VOID__STRING_INT_INT (GClosure     *closure,
                                             gpointer      marshal_data);
 #define e_marshal_NONE__STRING_INT_INT	e_marshal_VOID__STRING_INT_INT
 
-/* NONE:STRING,POINTER,POINTER (e-marshal.list:53) */
+/* NONE:STRING,POINTER,POINTER (e-marshal.list:56) */
 extern void e_marshal_VOID__STRING_POINTER_POINTER (GClosure     *closure,
                                                     GValue       *return_value,
                                                     guint         n_param_values,
@@ -462,7 +489,7 @@ extern void e_marshal_VOID__STRING_POINTER_POINTER (GClosure     *closure,
                                                     gpointer      marshal_data);
 #define e_marshal_NONE__STRING_POINTER_POINTER	e_marshal_VOID__STRING_POINTER_POINTER
 
-/* NONE:STRING,STRING (e-marshal.list:54) */
+/* NONE:STRING,STRING (e-marshal.list:57) */
 extern void e_marshal_VOID__STRING_STRING (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -471,16 +498,7 @@ extern void e_marshal_VOID__STRING_STRING (GClosure     *closure,
                                            gpointer      marshal_data);
 #define e_marshal_NONE__STRING_STRING	e_marshal_VOID__STRING_STRING
 
-/* NONE:STRING,STRING,UINT (e-marshal.list:55) */
-extern void e_marshal_VOID__STRING_STRING_UINT (GClosure     *closure,
-                                                GValue       *return_value,
-                                                guint         n_param_values,
-                                                const GValue *param_values,
-                                                gpointer      invocation_hint,
-                                                gpointer      marshal_data);
-#define e_marshal_NONE__STRING_STRING_UINT	e_marshal_VOID__STRING_STRING_UINT
-
-/* NONE:UINT,STRING (e-marshal.list:56) */
+/* NONE:UINT,STRING (e-marshal.list:58) */
 extern void e_marshal_VOID__UINT_STRING (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
@@ -489,7 +507,7 @@ extern void e_marshal_VOID__UINT_STRING (GClosure     *closure,
                                          gpointer      marshal_data);
 #define e_marshal_NONE__UINT_STRING	e_marshal_VOID__UINT_STRING
 
-/* STRING:NONE (e-marshal.list:57) */
+/* STRING:NONE (e-marshal.list:59) */
 extern void e_marshal_STRING__VOID (GClosure     *closure,
                                     GValue       *return_value,
                                     guint         n_param_values,
