@@ -28,6 +28,7 @@
 #include <camel/camel.h>
 
 #include <mail/e-mail-reader.h>
+#include <mail/e-mail-session.h>
 #include <mail/em-folder-tree.h>
 
 G_BEGIN_DECLS
@@ -35,14 +36,14 @@ G_BEGIN_DECLS
 struct _EMFormat;
 
 gboolean em_utils_ask_open_many (GtkWindow *parent, gint how_many);
-gboolean em_utils_prompt_user(GtkWindow *parent, const gchar *promptkey, const gchar *tag, ...);
+gboolean em_utils_prompt_user (GtkWindow *parent, const gchar *promptkey, const gchar *tag, ...);
 
 GPtrArray *em_utils_uids_copy (GPtrArray *uids);
 void em_utils_uids_free (GPtrArray *uids);
 
 gboolean em_utils_check_user_can_send_mail (void);
 
-void em_utils_edit_filters (GtkWidget *parent);
+void em_utils_edit_filters (GtkWidget *parent, EMailBackend *backend);
 void em_filename_make_safe (gchar *string);
 void em_utils_edit_vfolders (GtkWidget *parent);
 
@@ -52,40 +53,26 @@ void em_utils_flag_for_followup_completed (GtkWindow *parent, CamelFolder *folde
 
 /* This stuff that follows probably doesn't belong here, then again, the stuff above probably belongs elsewhere */
 
-void em_utils_selection_set_mailbox(GtkSelectionData *data, CamelFolder *folder, GPtrArray *uids);
-void em_utils_selection_get_mailbox(GtkSelectionData *data, CamelFolder *folder);
-void em_utils_selection_get_message(GtkSelectionData *data, CamelFolder *folder);
-/* FIXME: be nice if these also worked on CamelFolder's, no easy way to get uri from folder yet tho */
-void em_utils_selection_set_uidlist(GtkSelectionData *data, const gchar *uri, GPtrArray *uids);
-void em_utils_selection_get_uidlist(GtkSelectionData *data, CamelFolder *dest, gint move, GError **error);
-void em_utils_selection_set_urilist(GtkSelectionData *data, CamelFolder *folder, GPtrArray *uids);
-void em_utils_selection_get_urilist(GtkSelectionData *data, CamelFolder *folder);
+void em_utils_selection_set_mailbox (GtkSelectionData *data, CamelFolder *folder, GPtrArray *uids);
+void em_utils_selection_get_mailbox (GtkSelectionData *data, CamelFolder *folder);
+void em_utils_selection_get_message (GtkSelectionData *data, CamelFolder *folder);
+void em_utils_selection_set_uidlist (GtkSelectionData *data, CamelFolder *folder, GPtrArray *uids);
+void em_utils_selection_get_uidlist (GtkSelectionData *data, EMailSession *session, CamelFolder *dest, gint move, GCancellable *cancellable, GError **error);
+void em_utils_selection_set_urilist (GtkSelectionData *data, CamelFolder *folder, GPtrArray *uids);
+void em_utils_selection_get_urilist (GtkSelectionData *data, CamelFolder *folder);
 
-gchar *em_utils_temp_save_part(GtkWidget *parent, CamelMimePart *part, gboolean mode);
-
-gboolean em_utils_folder_is_drafts(CamelFolder *folder, const gchar *uri);
-gboolean em_utils_folder_is_templates(CamelFolder *folder, const gchar *uri);
-gboolean em_utils_folder_is_sent(CamelFolder *folder, const gchar *uri);
-gboolean em_utils_folder_is_outbox(CamelFolder *folder, const gchar *uri);
+gboolean	em_utils_folder_is_drafts	(CamelFolder *folder);
+gboolean	em_utils_folder_is_templates	(CamelFolder *folder);
+gboolean	em_utils_folder_is_sent		(CamelFolder *folder);
+gboolean	em_utils_folder_is_outbox	(CamelFolder *folder);
 
 gchar *em_utils_get_proxy_uri (const gchar *uri);
 
 /* FIXME: should this have an override charset? */
-gchar *em_utils_message_to_html (CamelMimeMessage *msg, const gchar *credits, guint32 flags, gssize *len, struct _EMFormat *source, const gchar *append, guint32 *validity_found);
+gchar *em_utils_message_to_html (CamelMimeMessage *msg, const gchar *credits, guint32 flags, struct _EMFormat *source, const gchar *append, guint32 *validity_found);
 
-void em_utils_expunge_folder (GtkWidget *parent, CamelFolder *folder);
-void em_utils_empty_trash (GtkWidget *parent);
-
-/* returns the folder name portion of an URI */
-gchar *em_utils_folder_name_from_uri (const gchar *uri);
-
-/* internal/camel uri translation */
-gchar *em_uri_from_camel (const gchar *curi);
-gchar *em_uri_to_camel (const gchar *euri);
-
-/* Run errors silently on the status bar */
-void em_utils_show_error_silent (GtkWidget *widget);
-void em_utils_show_info_silent (GtkWidget *widget);
+void em_utils_expunge_folder (GtkWidget *parent, EMailBackend *backend, CamelFolder *folder);
+void em_utils_empty_trash (GtkWidget *parent, EMailBackend *backend);
 
 /* is this address in the addressbook?  caches results */
 gboolean em_utils_in_addressbook (CamelInternetAddress *addr, gboolean local_only);
@@ -107,6 +94,11 @@ void emu_free_mail_cache (void);
 
 void emu_restore_folder_tree_state (EMFolderTree *folder_tree);
 
+gboolean em_utils_is_local_delivery_mbox_file (CamelURL *url);
+
+gboolean em_utils_connect_service_sync (CamelService *service, GCancellable *cancellable, GError **error);
+gboolean em_utils_disconnect_service_sync (CamelService *service, gboolean clean, GCancellable *cancellable, GError **error);
+
 G_END_DECLS
 
 #endif /* __EM_UTILS_H__ */
